@@ -1,7 +1,4 @@
-package Path::Resolver::Resolver::DataSection;
-{
-  $Path::Resolver::Resolver::DataSection::VERSION = '3.100454';
-}
+package Path::Resolver::Resolver::DataSection 3.100455;
 # ABSTRACT: find content in a package's Data::Section content
 use Moose;
 with 'Path::Resolver::Role::Resolver';
@@ -14,6 +11,28 @@ use Path::Resolver::SimpleEntity;
 
 sub native_type { class_type('Path::Resolver::SimpleEntity') }
 
+#pod =head1 SYNOPSIS
+#pod
+#pod   my $resolver = Path::Resolver::Resolver::DataSection->new({
+#pod     module => 'YourApp::Config::InData',
+#pod   });
+#pod
+#pod   my $simple_entity = $resolver->entity_at('foo/bar.txt');
+#pod
+#pod This class assumes that you will give it the name of another package and that
+#pod that package uses L<Data::Section|Data::Section> to retrieve named content from
+#pod its C<DATA> blocks and those of its parent classes.
+#pod
+#pod The native type of this resolver is a class type of
+#pod L<Path::Resolver::SimpleEntity|Path::Resolver::SimpleEntity> and it has no
+#pod default converter.
+#pod
+#pod =attr module
+#pod
+#pod This is the name of the module to load and is also used as the package (class)
+#pod on which to call the data-finding method.
+#pod
+#pod =cut
 
 has module => (
   is       => 'ro',
@@ -21,6 +40,12 @@ has module => (
   required => 1,
 );
 
+#pod =attr data_method
+#pod
+#pod This attribute may be given to supply a method name to call to find content in
+#pod a package.  The default is Data::Section's default: C<section_data>.
+#pod
+#pod =cut
 
 has data_method => (
   is  => 'ro',
@@ -52,13 +77,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Path::Resolver::Resolver::DataSection - find content in a package's Data::Section content
 
 =head1 VERSION
 
-version 3.100454
+version 3.100455
 
 =head1 SYNOPSIS
 
@@ -76,6 +103,16 @@ The native type of this resolver is a class type of
 L<Path::Resolver::SimpleEntity|Path::Resolver::SimpleEntity> and it has no
 default converter.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 module
@@ -90,11 +127,11 @@ a package.  The default is Data::Section's default: C<section_data>.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
