@@ -1,7 +1,4 @@
-package Path::Resolver::Resolver::Hash;
-{
-  $Path::Resolver::Resolver::Hash::VERSION = '3.100454';
-}
+package Path::Resolver::Resolver::Hash 3.100455;
 # ABSTRACT: glorified hash lookup
 use Moose;
 with 'Path::Resolver::Role::Resolver';
@@ -11,9 +8,36 @@ use namespace::autoclean;
 use Moose::Util::TypeConstraints;
 use Path::Resolver::SimpleEntity;
 
+#pod =head1 SYNOPSIS
+#pod
+#pod   my $resolver = Path::Resolver::Resolver::Hash->new({
+#pod     hash => {
+#pod       foo => {
+#pod         'bar.txt' => "This is the content.\n",
+#pod       },
+#pod     }
+#pod   });
+#pod
+#pod   my $simple_entity = $resolver->entity_at('foo/bar.txt');
+#pod
+#pod This resolver looks through a has to find string content.  Path parts are used
+#pod to drill down through the hash.  The final result must be a string.  Unless you
+#pod really know what you're doing, it should be a byte string and not a character
+#pod string.
+#pod
+#pod The native type of the Hash resolver is a class type of
+#pod Path::Resolver::SimpleEntity.  There is no default converter.
+#pod
+#pod =cut
 
 sub native_type { class_type('Path::Resolver::SimpleEntity') }
 
+#pod =attr hash
+#pod
+#pod This is a hash reference in which lookups are performed.  References to copies
+#pod of the string values are returned.
+#pod
+#pod =cut
 
 has hash => (
   is       => 'ro',
@@ -63,13 +87,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Path::Resolver::Resolver::Hash - glorified hash lookup
 
 =head1 VERSION
 
-version 3.100454
+version 3.100455
 
 =head1 SYNOPSIS
 
@@ -91,6 +117,16 @@ string.
 The native type of the Hash resolver is a class type of
 Path::Resolver::SimpleEntity.  There is no default converter.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 hash
@@ -100,11 +136,11 @@ of the string values are returned.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
